diff --git a/classes/admin_settingspage_tabs.php b/classes/admin_settingspage_tabs.php
index dca6242..1a436f6 100644
--- a/classes/admin_settingspage_tabs.php
+++ b/classes/admin_settingspage_tabs.php
@@ -15,7 +15,7 @@
// along with Moodle. If not, see .
/**
- * @package theme_boost
+ * @package theme_ilb
* @copyright 2016 Ryan Wyllie
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
@@ -23,11 +23,11 @@
defined('MOODLE_INTERNAL') || die();
/**
- * @package theme_boost
+ * @package theme_ilb
* @copyright 2016 Ryan Wyllie
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
-class theme_boost_admin_settingspage_tabs extends admin_settingpage {
+class theme_ilb_admin_settingspage_tabs extends admin_settingpage {
/** @var The tabs */
protected $tabs = array();
@@ -93,7 +93,7 @@ class theme_boost_admin_settingspage_tabs extends admin_settingpage {
return '';
}
- return $OUTPUT->render_from_template('theme_boost/admin_setting_tabs', $context);
+ return $OUTPUT->render_from_template('theme_ilb/admin_setting_tabs', $context);
}
}
diff --git a/classes/output/core_renderer.php b/classes/output/core_renderer.php
index 05c2ef8..1c7842b 100644
--- a/classes/output/core_renderer.php
+++ b/classes/output/core_renderer.php
@@ -14,7 +14,7 @@
// You should have received a copy of the GNU General Public License
// along with Moodle. If not, see .
-namespace theme_boost\output;
+namespace theme_ilb\output;
use moodle_url;
@@ -23,7 +23,7 @@ defined('MOODLE_INTERNAL') || die;
/**
* Renderers to align Moodle's HTML with that expected by Bootstrap
*
- * @package theme_boost
+ * @package theme_ilb
* @copyright 2012 Bas Brands, www.basbrands.nl
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
diff --git a/config.php b/config.php
index 8952583..2128789 100644
--- a/config.php
+++ b/config.php
@@ -15,9 +15,9 @@
// along with Moodle. If not, see .
/**
- * Boost config.
+ * Ilb config.
*
- * @package theme_boost
+ * @package theme_ilb
* @copyright 2016 Frédéric Massart
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
@@ -26,13 +26,13 @@ defined('MOODLE_INTERNAL') || die();
require_once(__DIR__ . '/lib.php');
-$THEME->name = 'boost';
+$THEME->name = 'ilb';
$THEME->sheets = [];
$THEME->editor_sheets = [];
$THEME->editor_scss = ['editor'];
$THEME->usefallback = true;
$THEME->scss = function($theme) {
- return theme_boost_get_main_scss_content($theme);
+ return theme_ilb_get_main_scss_content($theme);
};
$THEME->layouts = [
@@ -149,9 +149,9 @@ $THEME->layouts = [
$THEME->parents = [];
$THEME->enable_dock = false;
-$THEME->extrascsscallback = 'theme_boost_get_extra_scss';
-$THEME->prescsscallback = 'theme_boost_get_pre_scss';
-$THEME->precompiledcsscallback = 'theme_boost_get_precompiled_css';
+$THEME->extrascsscallback = 'theme_ilb_get_extra_scss';
+$THEME->prescsscallback = 'theme_ilb_get_pre_scss';
+$THEME->precompiledcsscallback = 'theme_ilb_get_precompiled_css';
$THEME->yuicssmodules = array();
$THEME->rendererfactory = 'theme_overridden_renderer_factory';
$THEME->requiredblocks = '';
diff --git a/lib.php b/lib.php
index cf8b7fe..3972e14 100644
--- a/lib.php
+++ b/lib.php
@@ -17,7 +17,7 @@
/**
* Theme functions.
*
- * @package theme_boost
+ * @package theme_ilb
* @copyright 2016 Frédéric Massart - FMCorz.net
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
@@ -30,10 +30,10 @@ defined('MOODLE_INTERNAL') || die();
* @param string $tree The CSS tree.
* @param theme_config $theme The theme config object.
*/
-function theme_boost_css_tree_post_processor($tree, $theme) {
- error_log('theme_boost_css_tree_post_processor() is deprecated. Required' .
- 'prefixes for Bootstrap are now in theme/boost/scss/moodle/prefixes.scss');
- $prefixer = new theme_boost\autoprefixer($tree);
+function theme_ilb_css_tree_post_processor($tree, $theme) {
+ error_log('theme_ilb_css_tree_post_processor() is deprecated. Required' .
+ 'prefixes for Bootstrap are now in theme/ilb/scss/moodle/prefixes.scss');
+ $prefixer = new theme_ilb\autoprefixer($tree);
$prefixer->prefix();
}
@@ -43,7 +43,7 @@ function theme_boost_css_tree_post_processor($tree, $theme) {
* @param theme_config $theme The theme config object.
* @return string
*/
-function theme_boost_get_extra_scss($theme) {
+function theme_ilb_get_extra_scss($theme) {
$content = '';
$imageurl = $theme->setting_file_url('backgroundimage', 'backgroundimage');
@@ -70,9 +70,9 @@ function theme_boost_get_extra_scss($theme) {
* @param array $options
* @return bool
*/
-function theme_boost_pluginfile($course, $cm, $context, $filearea, $args, $forcedownload, array $options = array()) {
+function theme_ilb_pluginfile($course, $cm, $context, $filearea, $args, $forcedownload, array $options = array()) {
if ($context->contextlevel == CONTEXT_SYSTEM && ($filearea === 'logo' || $filearea === 'backgroundimage')) {
- $theme = theme_config::load('boost');
+ $theme = theme_config::load('ilb');
// By default, theme files must be cache-able by both browsers and proxies.
if (!array_key_exists('cacheability', $options)) {
$options['cacheability'] = 'public';
@@ -89,7 +89,7 @@ function theme_boost_pluginfile($course, $cm, $context, $filearea, $args, $force
* @param theme_config $theme The theme config object.
* @return string
*/
-function theme_boost_get_main_scss_content($theme) {
+function theme_ilb_get_main_scss_content($theme) {
global $CFG;
$scss = '';
@@ -98,14 +98,14 @@ function theme_boost_get_main_scss_content($theme) {
$context = context_system::instance();
if ($filename == 'default.scss') {
- $scss .= file_get_contents($CFG->dirroot . '/theme/boost/scss/preset/default.scss');
+ $scss .= file_get_contents($CFG->dirroot . '/theme/ilb/scss/preset/default.scss');
} else if ($filename == 'plain.scss') {
- $scss .= file_get_contents($CFG->dirroot . '/theme/boost/scss/preset/plain.scss');
- } else if ($filename && ($presetfile = $fs->get_file($context->id, 'theme_boost', 'preset', 0, '/', $filename))) {
+ $scss .= file_get_contents($CFG->dirroot . '/theme/ilb/scss/preset/plain.scss');
+ } else if ($filename && ($presetfile = $fs->get_file($context->id, 'theme_ilb', 'preset', 0, '/', $filename))) {
$scss .= $presetfile->get_content();
} else {
// Safety fallback - maybe new installs etc.
- $scss .= file_get_contents($CFG->dirroot . '/theme/boost/scss/preset/default.scss');
+ $scss .= file_get_contents($CFG->dirroot . '/theme/ilb/scss/preset/default.scss');
}
return $scss;
@@ -116,9 +116,9 @@ function theme_boost_get_main_scss_content($theme) {
*
* @return string compiled css
*/
-function theme_boost_get_precompiled_css() {
+function theme_ilb_get_precompiled_css() {
global $CFG;
- return file_get_contents($CFG->dirroot . '/theme/boost/style/moodle.css');
+ return file_get_contents($CFG->dirroot . '/theme/ilb/style/moodle.css');
}
/**
@@ -127,7 +127,7 @@ function theme_boost_get_precompiled_css() {
* @param theme_config $theme The theme config object.
* @return array
*/
-function theme_boost_get_pre_scss($theme) {
+function theme_ilb_get_pre_scss($theme) {
global $CFG;
$scss = '';
diff --git a/scss/fontawesome/readme_moodle.txt b/scss/fontawesome/readme_moodle.txt
index bd0fe2e..075593f 100644
--- a/scss/fontawesome/readme_moodle.txt
+++ b/scss/fontawesome/readme_moodle.txt
@@ -3,5 +3,5 @@ Description of Font awesome import into Moodle
Font awesome comes in 3 parts relating to Moodle.
1. The font. Put the woff font in lib/fonts/fontawesome-webfont.woff. Update lib/thirdpartylibs.xml.
-2. SCSS. Replace the SCSS in this folder (/theme/boost/scss/fontawesome). Update theme/boost/thirdpartylibs.xml.
+2. SCSS. Replace the SCSS in this folder (/theme/ilb/scss/fontawesome). Update theme/ilb/thirdpartylibs.xml.
3. The @import "path" is commented because we provide the font path differently e.g. "[[font:core|fontawesome-webfont.eot]]"
diff --git a/scss/moodle/core.scss b/scss/moodle/core.scss
index 4915c7f..9537420 100644
--- a/scss/moodle/core.scss
+++ b/scss/moodle/core.scss
@@ -1,6 +1,6 @@
/* core.less */
-// When we upgrade boostrap to v4 release, we will need to change this to be used by the text-white class.
+// When we upgrade ilbrap to v4 release, we will need to change this to be used by the text-white class.
// Because a primary colour that is both AA accessible on grey (footer) and white is not possible, we always
// want white default colour.
$bg-inverse-link-color: #fff !default;
diff --git a/scss/preset/plain.scss b/scss/preset/plain.scss
index 7dfb29c..7f568f1 100644
--- a/scss/preset/plain.scss
+++ b/scss/preset/plain.scss
@@ -6,7 +6,7 @@
* To create your own preset file:
* - Duplicate this file and rename it, for instance to preset-apple.scss.
* - In settings.php, find the references to 'plain', duplicate them and rename
- * them to 'apple'. (Look around the choices for 'theme_boost/preset').
+ * them to 'apple'. (Look around the choices for 'theme_ilb/preset').
*/
// Import FontAwesome.
diff --git a/settings.php b/settings.php
index 1f2bad2..3f1e1c3 100644
--- a/settings.php
+++ b/settings.php
@@ -15,7 +15,7 @@
// along with Moodle. If not, see .
/**
- * @package theme_boost
+ * @package theme_ilb
* @copyright 2016 Ryan Wyllie
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
@@ -23,18 +23,18 @@
defined('MOODLE_INTERNAL') || die();
if ($ADMIN->fulltree) {
- $settings = new theme_boost_admin_settingspage_tabs('themesettingboost', get_string('configtitle', 'theme_boost'));
- $page = new admin_settingpage('theme_boost_general', get_string('generalsettings', 'theme_boost'));
+ $settings = new theme_ilb_admin_settingspage_tabs('themesettingilb', get_string('configtitle', 'theme_ilb'));
+ $page = new admin_settingpage('theme_ilb_general', get_string('generalsettings', 'theme_ilb'));
// Preset.
- $name = 'theme_boost/preset';
- $title = get_string('preset', 'theme_boost');
- $description = get_string('preset_desc', 'theme_boost');
+ $name = 'theme_ilb/preset';
+ $title = get_string('preset', 'theme_ilb');
+ $description = get_string('preset_desc', 'theme_ilb');
$default = 'default.scss';
$context = context_system::instance();
$fs = get_file_storage();
- $files = $fs->get_area_files($context->id, 'theme_boost', 'preset', 0, 'itemid, filepath, filename', false);
+ $files = $fs->get_area_files($context->id, 'theme_ilb', 'preset', 0, 'itemid, filepath, filename', false);
$choices = [];
foreach ($files as $file) {
@@ -44,32 +44,32 @@ if ($ADMIN->fulltree) {
$choices['default.scss'] = 'default.scss';
$choices['plain.scss'] = 'plain.scss';
- $setting = new admin_setting_configthemepreset($name, $title, $description, $default, $choices, 'boost');
+ $setting = new admin_setting_configthemepreset($name, $title, $description, $default, $choices, 'ilb');
$setting->set_updatedcallback('theme_reset_all_caches');
$page->add($setting);
// Preset files setting.
- $name = 'theme_boost/presetfiles';
- $title = get_string('presetfiles','theme_boost');
- $description = get_string('presetfiles_desc', 'theme_boost');
+ $name = 'theme_ilb/presetfiles';
+ $title = get_string('presetfiles','theme_ilb');
+ $description = get_string('presetfiles_desc', 'theme_ilb');
$setting = new admin_setting_configstoredfile($name, $title, $description, 'preset', 0,
array('maxfiles' => 20, 'accepted_types' => array('.scss')));
$page->add($setting);
// Background image setting.
- $name = 'theme_boost/backgroundimage';
- $title = get_string('backgroundimage', 'theme_boost');
- $description = get_string('backgroundimage_desc', 'theme_boost');
+ $name = 'theme_ilb/backgroundimage';
+ $title = get_string('backgroundimage', 'theme_ilb');
+ $description = get_string('backgroundimage_desc', 'theme_ilb');
$setting = new admin_setting_configstoredfile($name, $title, $description, 'backgroundimage');
$setting->set_updatedcallback('theme_reset_all_caches');
$page->add($setting);
// Variable $body-color.
// We use an empty default value because the default colour should come from the preset.
- $name = 'theme_boost/brandcolor';
- $title = get_string('brandcolor', 'theme_boost');
- $description = get_string('brandcolor_desc', 'theme_boost');
+ $name = 'theme_ilb/brandcolor';
+ $title = get_string('brandcolor', 'theme_ilb');
+ $description = get_string('brandcolor_desc', 'theme_ilb');
$setting = new admin_setting_configcolourpicker($name, $title, $description, '');
$setting->set_updatedcallback('theme_reset_all_caches');
$page->add($setting);
@@ -78,17 +78,17 @@ if ($ADMIN->fulltree) {
$settings->add($page);
// Advanced settings.
- $page = new admin_settingpage('theme_boost_advanced', get_string('advancedsettings', 'theme_boost'));
+ $page = new admin_settingpage('theme_ilb_advanced', get_string('advancedsettings', 'theme_ilb'));
// Raw SCSS to include before the content.
- $setting = new admin_setting_scsscode('theme_boost/scsspre',
- get_string('rawscsspre', 'theme_boost'), get_string('rawscsspre_desc', 'theme_boost'), '', PARAM_RAW);
+ $setting = new admin_setting_scsscode('theme_ilb/scsspre',
+ get_string('rawscsspre', 'theme_ilb'), get_string('rawscsspre_desc', 'theme_ilb'), '', PARAM_RAW);
$setting->set_updatedcallback('theme_reset_all_caches');
$page->add($setting);
// Raw SCSS to include after the content.
- $setting = new admin_setting_scsscode('theme_boost/scss', get_string('rawscss', 'theme_boost'),
- get_string('rawscss_desc', 'theme_boost'), '', PARAM_RAW);
+ $setting = new admin_setting_scsscode('theme_ilb/scss', get_string('rawscss', 'theme_ilb'),
+ get_string('rawscss_desc', 'theme_ilb'), '', PARAM_RAW);
$setting->set_updatedcallback('theme_reset_all_caches');
$page->add($setting);
diff --git a/templates/admin_setting_tabs.mustache b/templates/admin_setting_tabs.mustache
index 162314a..1968004 100644
--- a/templates/admin_setting_tabs.mustache
+++ b/templates/admin_setting_tabs.mustache
@@ -15,7 +15,7 @@
along with Moodle. If not, see .
}}
{{!
- @template theme_boost/admin_setting_tabs
+ @template theme_ilb/admin_setting_tabs
Example context (json):
diff --git a/templates/columns1.mustache b/templates/columns1.mustache
index 51fb23e..eeb1e0f 100644
--- a/templates/columns1.mustache
+++ b/templates/columns1.mustache
@@ -15,9 +15,9 @@
along with Moodle. If not, see .
}}
{{!
- @template theme_boost/columns1
+ @template theme_ilb/columns1
- Boost 1 column layout template.
+ Ilb 1 column layout template.
Context variables required for this template:
* sitename - The name of the site
@@ -36,7 +36,7 @@
"bodyattributes":""
}
}}
-{{> theme_boost/head }}
+{{> theme_ilb/head }}
{{> core/local/toast/wrapper}}
@@ -65,8 +65,8 @@
diff --git a/classes/autoprefixer.php b/classes/autoprefixer.php
index 9353d2a..3d496b5 100644
--- a/classes/autoprefixer.php
+++ b/classes/autoprefixer.php
@@ -18,15 +18,15 @@
* Autoprefixer.
*
* This autoprefixer has been developed to satisfy the basic needs of the
* theme Boost when working with Bootstrap 4 alpha. We do not recommend
* that this tool is shared, nor used outside of this theme.
*
- * @package theme_boost
+ * @package theme_ilb
* @copyright 2016 Frédéric Massart - FMCorz.net
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
-namespace theme_boost;
+namespace theme_ilb;
defined('MOODLE_INTERNAL') || die();
use Sabberworm\CSS\CSSList\CSSList;
@@ -54,7 +54,7 @@ use Sabberworm\CSS\Value\ValueList;
*
* Very basic implementation covering simple needs for Bootstrap 4.
*
- * @package theme_boost
+ * @package theme_ilb
* @copyright 2016 Frédéric Massart - FMCorz.net
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
@@ -104,8 +104,8 @@ class autoprefixer {
* @param Document $tree The CSS tree.
*/
public function __construct(Document $tree) {
- debugging('theme_boost\autoprefixer() is deprecated. Required prefixes for Bootstrap ' .
- 'are now in theme/boost/scss/moodle/prefixes.scss', DEBUG_DEVELOPER);
+ debugging('theme_ilb\autoprefixer() is deprecated. Required prefixes for Bootstrap ' .
+ 'are now in theme/ilb/scss/moodle/prefixes.scss', DEBUG_DEVELOPER);
$this->tree = $tree;
$pseudos = array_map(function($pseudo) {
@@ -18,15 +18,15 @@
*
* This autoprefixer has been developed to satisfy the basic needs of the
- * theme Boost when working with Bootstrap 4 alpha. We do not recommend
+ * theme Ilb when working with Bootstrap 4 alpha. We do not recommend
* that this tool is shared, nor used outside of this theme.
*
diff --git a/classes/privacy/provider.php b/classes/privacy/provider.php
index 379e50b..510cf57 100644
--- a/classes/privacy/provider.php
+++ b/classes/privacy/provider.php
@@ -15,21 +15,21 @@
// along with Moodle. If not, see .
/**
* Privacy Subsystem implementation for theme_boost.
*
- * @package theme_boost
+ * @package theme_ilb
* @copyright 2018 Andrew Nicols
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
-namespace theme_boost\privacy;
+namespace theme_ilb\privacy;
use \core_privacy\local\metadata\collection;
defined('MOODLE_INTERNAL') || die();
/**
* The boost theme stores a user preference data.
*
* @copyright 2018 Andrew Nicols
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
@@ -63,12 +63,12 @@ class provider implements
$draweropennavpref = get_user_preferences(self::DRAWER_OPEN_NAV, null, $userid);
if (isset($draweropennavpref)) {
- $preferencestring = get_string('privacy:drawernavclosed', 'theme_boost');
+ $preferencestring = get_string('privacy:drawernavclosed', 'theme_ilb');
if ($draweropennavpref == 'true') {
- $preferencestring = get_string('privacy:drawernavopen', 'theme_boost');
+ $preferencestring = get_string('privacy:drawernavopen', 'theme_ilb');
}
\core_privacy\local\request\writer::export_user_preference(
- 'theme_boost',
+ 'theme_ilb',
self::DRAWER_OPEN_NAV,
$draweropennavpref,
$preferencestring
@@ -15,21 +15,21 @@
// along with Moodle. If not, see .
/**
- * Privacy Subsystem implementation for theme_boost.
+ * Privacy Subsystem implementation for theme_ilb.
*
@@ -15,21 +15,21 @@
defined('MOODLE_INTERNAL') || die();
/**
- * The boost theme stores a user preference data.
+ * The ilb theme stores a user preference data.
*
* @copyright 2018 Andrew Nicols
diff --git a/layout/columns1.php b/layout/columns1.php
index d5b0412..5f647bf 100644
--- a/layout/columns1.php
+++ b/layout/columns1.php
@@ -15,9 +15,9 @@
// along with Moodle. If not, see .
/**
* A one column layout for the boost theme.
*
- * @package theme_boost
+ * @package theme_ilb
* @copyright 2016 Damyon Wiese
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
@@ -32,5 +32,5 @@ $templatecontext = [
'bodyattributes' => $bodyattributes
];
-echo $OUTPUT->render_from_template('theme_boost/columns1', $templatecontext);
+echo $OUTPUT->render_from_template('theme_ilb/columns1', $templatecontext);
@@ -15,9 +15,9 @@
// along with Moodle. If not, see .
/**
- * A one column layout for the boost theme.
+ * A one column layout for the ilb theme.
*
diff --git a/layout/columns2.php b/layout/columns2.php
index 384158d..0a4541c 100644
--- a/layout/columns2.php
+++ b/layout/columns2.php
@@ -15,9 +15,9 @@
// along with Moodle. If not, see .
/**
* A two column layout for the boost theme.
*
- * @package theme_boost
+ * @package theme_ilb
* @copyright 2016 Damyon Wiese
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
@@ -56,5 +56,5 @@ $templatecontext = [
$nav = $PAGE->flatnav;
$templatecontext['flatnavigation'] = $nav;
$templatecontext['firstcollectionlabel'] = $nav->get_collectionlabel();
-echo $OUTPUT->render_from_template('theme_boost/columns2', $templatecontext);
+echo $OUTPUT->render_from_template('theme_ilb/columns2', $templatecontext);
@@ -15,9 +15,9 @@
// along with Moodle. If not, see .
/**
- * A two column layout for the boost theme.
+ * A two column layout for the ilb theme.
*
diff --git a/layout/embedded.php b/layout/embedded.php
index 762d7f3..ecb418e 100644
--- a/layout/embedded.php
+++ b/layout/embedded.php
@@ -15,9 +15,9 @@
// along with Moodle. If not, see .
/**
* An embedded layout for the boost theme.
*
- * @package theme_boost
+ * @package theme_ilb
* @copyright 2016 Damyon Wiese
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
@@ -33,4 +33,4 @@ $templatecontext = [
'fakeblocks' => $fakeblockshtml,
];
-echo $OUTPUT->render_from_template('theme_boost/embedded', $templatecontext);
+echo $OUTPUT->render_from_template('theme_ilb/embedded', $templatecontext);
@@ -15,9 +15,9 @@
// along with Moodle. If not, see .
/**
- * An embedded layout for the boost theme.
+ * An embedded layout for the ilb theme.
*
diff --git a/layout/login.php b/layout/login.php
index e86169d..3e17e01 100644
--- a/layout/login.php
+++ b/layout/login.php
@@ -17,9 +17,9 @@
defined('MOODLE_INTERNAL') || die();
/**
* A login page layout for the boost theme.
*
- * @package theme_boost
+ * @package theme_ilb
* @copyright 2016 Damyon Wiese
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
@@ -32,5 +32,5 @@ $templatecontext = [
'bodyattributes' => $bodyattributes
];
-echo $OUTPUT->render_from_template('theme_boost/login', $templatecontext);
+echo $OUTPUT->render_from_template('theme_ilb/login', $templatecontext);
@@ -17,9 +17,9 @@
defined('MOODLE_INTERNAL') || die();
/**
- * A login page layout for the boost theme.
+ * A login page layout for the ilb theme.
*
diff --git a/layout/maintenance.php b/layout/maintenance.php
index 953debe..eb3f7e0 100644
--- a/layout/maintenance.php
+++ b/layout/maintenance.php
@@ -15,9 +15,9 @@
// along with Moodle. If not, see .
/**
* A maintenance layout for the boost theme.
*
- * @package theme_boost
+ * @package theme_ilb
* @copyright 2016 Damyon Wiese
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
@@ -31,4 +31,4 @@ $templatecontext = [
'output' => $OUTPUT
];
-echo $OUTPUT->render_from_template('theme_boost/maintenance', $templatecontext);
+echo $OUTPUT->render_from_template('theme_ilb/maintenance', $templatecontext);
@@ -15,9 +15,9 @@
// along with Moodle. If not, see .
/**
- * A maintenance layout for the boost theme.
+ * A maintenance layout for the ilb theme.
*
diff --git a/layout/secure.php b/layout/secure.php
index 74fe3f9..be95242 100644
--- a/layout/secure.php
+++ b/layout/secure.php
@@ -15,9 +15,9 @@
// along with Moodle. If not, see .
/**
* A secure layout for the boost theme.
*
- * @package theme_boost
+ * @package theme_ilb
* @copyright 2016 Damyon Wiese
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
@@ -36,5 +36,5 @@ $templatecontext = [
'hasblocks' => $hasblocks
];
-echo $OUTPUT->render_from_template('theme_boost/secure', $templatecontext);
+echo $OUTPUT->render_from_template('theme_ilb/secure', $templatecontext);
@@ -15,9 +15,9 @@
// along with Moodle. If not, see .
/**
- * A secure layout for the boost theme.
+ * A secure layout for the ilb theme.
*